@@ -18,17 +18,19 @@
 ## along with Gajim.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import locale, random
+import locale
 from hashlib import sha1
-from transports_nb import NonBlockingTransport, NonBlockingHTTPBOSH,\
+from .transports_nb import NonBlockingTransport, NonBlockingHTTPBOSH,\
         CONNECTED, CONNECTING, DISCONNECTED, DISCONNECTING,\
         urisplit, DISCONNECT_TIMEOUT_SECONDS
-from protocol import BOSHBody, Protocol, NS_CLIENT
-from simplexml import Node
+from .protocol import BOSHBody, Protocol, NS_CLIENT
+from .simplexml import Node
 
 import logging
 log = logging.getLogger('nbxmpp.bosh')
 
+from . import rndg
+
 KEY_COUNT = 10
 
 # Fake file descriptor - it's used for setting read_timeout in idlequeue for
@@ -37,10 +39,10 @@ FAKE_DESCRIPTOR = -1337
 
 
 class NonBlockingBOSH(NonBlockingTransport):
-    def __init__(self, raise_event, on_disconnect, idlequeue, estabilish_tls, certs,
-                    xmpp_server, domain, bosh_dict, proxy_creds):
-        NonBlockingTransport.__init__(self, raise_event, on_disconnect, idlequeue,
-                estabilish_tls, certs)
+    def __init__(self, raise_event, on_disconnect, idlequeue, estabilish_tls,
+    certs, tls_version, cipher_list, xmpp_server, domain, bosh_dict, proxy_creds):
+        NonBlockingTransport.__init__(self, raise_event, on_disconnect,
+            idlequeue, estabilish_tls, certs, tls_version, cipher_list)
 
         self.bosh_sid = None
         if locale.getdefaultlocale()[0]:
@@ -68,6 +70,8 @@ class NonBlockingBOSH(NonBlockingTransport):
             self.bosh_secure = 'true'
         else:
             self.bosh_secure = 'false'
+        self.tls_version = tls_version
+        self.cipher_list = cipher_list
         self.use_proxy_auth = bosh_dict['useauth']
         self.proxy_creds = proxy_creds
         self.wait_cb_time = None
@@ -89,10 +93,8 @@ class NonBlockingBOSH(NonBlockingTransport):
             self.proxy_dict['credentials'] = self.proxy_creds
 
         # ssl variables
-        self.ssl_fingerprint_sha1 = []
-        self.ssl_certificate = []
-        self.ssl_errnum = []
-        self.ssl_cert_pem = []
+        self.ssl_certificate = None
+        self.ssl_errnum = 0
 
 
     def connect(self, conn_5tuple, on_connect, on_connect_failure):
@@ -128,7 +130,7 @@ class NonBlockingBOSH(NonBlockingTransport):
         if self.get_state() != DISCONNECTED and self.fd != -1:
             NonBlockingTransport.set_timeout(self, timeout)
         else:
-            log.warn('set_timeout: TIMEOUT NOT SET: state is %s, fd is %s' % (self.get_state(), self.fd))
+            log.warning('set_timeout: TIMEOUT NOT SET: state is %s, fd is %s' % (self.get_state(), self.fd))
 
     def on_http_request_possible(self):
         """
@@ -215,7 +217,7 @@ class NonBlockingBOSH(NonBlockingTransport):
         # sent after HTTP response from CM, exception is when we're disconnecting - then we
         # send anyway
         if total_pending_reqs >= self.bosh_requests and self.get_state()!=DISCONNECTING:
-            log.warn('attemp to make more requests than allowed by Connection Manager:\n%s' %
+            log.warning('attemp to make more requests than allowed by Connection Manager:\n%s' %
                     self.get_current_state())
             return
 
@@ -308,7 +310,7 @@ class NonBlockingBOSH(NonBlockingTransport):
         :param socket: disconnected transport object
         """
         if socket.http_persistent:
-            log.warn('Fallback to nonpersistent HTTP (no pipelining as well)')
+            log.warning('Fallback to nonpersistent HTTP (no pipelining as well)')
             socket.http_persistent = False
             self.http_persistent = False
             self.http_pipelining = False
@@ -327,27 +329,27 @@ class NonBlockingBOSH(NonBlockingTransport):
         self.remove_bosh_wait_timeout()
 
         if self.after_init:
-            if stanza_attrs.has_key('sid'):
+            if 'sid' in stanza_attrs:
                 # session ID should be only in init response
                 self.bosh_sid = stanza_attrs['sid']
 
-            if stanza_attrs.has_key('requests'):
+            if 'requests' in stanza_attrs:
                 self.bosh_requests = int(stanza_attrs['requests'])
 
-            if stanza_attrs.has_key('wait'):
+            if 'wait' in stanza_attrs:
                 self.bosh_wait = int(stanza_attrs['wait'])
             self.after_init = False
 
         ack = None
-        if stanza_attrs.has_key('ack'):
+        if 'ack' in stanza_attrs:
             ack = stanza_attrs['ack']
         self.ack_checker.process_incoming_ack(ack=ack,
                 socket=self.current_recv_socket)
 
-        if stanza_attrs.has_key('type'):
+        if 'type' in stanza_attrs:
             if stanza_attrs['type'] in ['terminate', 'terminal']:
                 condition = 'n/a'
-                if stanza_attrs.has_key('condition'):
+                if 'condition' in stanza_attrs:
                     condition = stanza_attrs['condition']
                 if condition == 'n/a':
                     log.info('Received sesion-ending terminating stanza')
@@ -450,6 +452,8 @@ class NonBlockingBOSH(NonBlockingTransport):
                 on_disconnect=self.disconnect,
                 idlequeue = self.idlequeue,
                 estabilish_tls = self.estabilish_tls,
+                tls_version = self.tls_version,
+                cipher_list = self.cipher_list,
                 certs = self.certs,
                 on_http_request_possible = self.on_http_request_possible,
                 http_dict = http_dict,
@@ -486,9 +490,7 @@ def get_rand_number():
     # to 7881299347898368 messages to raise rid over 2**53
     # (see http://www.xmpp.org/extensions/xep-0124.html#rids)
     # it's also used for sequence key initialization
-    r = random.Random()
-    r.seed()
-    return r.getrandbits(50)
+    return rndg.getrandbits(50)
 
 
 
